@@ -95,7 +95,7 @@ class EventHandler(CaseEventHandler, VariantEventHandler):
         """Fetch events from the database.
 
           Args:
-            institute (dict): A institute
+            institute (dict): An institute
             case (dict): A case
             variant_id (str, optional): global variant id
             level (str, optional): restrict comments to 'specific' or 'global'
@@ -374,3 +374,53 @@ class EventHandler(CaseEventHandler, VariantEventHandler):
                 content=content,
             )
         return comment
+
+    def comments_reupload(self, old_var, new_var, institute_obj, case_obj):
+        """Creates comments for a new variant after variant reupload
+
+        Accepts:
+            old_var(Variant): the deleted variant
+            new_var(Variant): the new variant replacing old_var
+            institute_obj(dict): an institute object
+            case_obj(dict): a case object
+
+        Returns:
+            new_comments(int): the number of created comments
+        """
+        new_comments = 0
+
+        if new_var["_id"] == old_var["_id"]:
+            return new_comments
+
+        link = "/{0}/{1}/{2}".format(
+            new_var["institute"], case_obj["display_name"], new_var["_id"]
+        )
+
+        # collect all comments for the old variant
+        comments_query = self.events(
+            variant_id=old_var["variant_id"],
+            comments=True,
+            institute=institute_obj,
+            case=case_obj,
+        )
+
+        # and create the same comment for the new variant
+        for old_comment in comments_query:
+
+            comment_user = self.user(old_comment["user_id"])
+            if comment_user is None:
+                continue
+
+            updated_comment = self.comment(
+                institute=institute_obj,
+                case=case_obj,
+                user=comment_user,
+                link=link,
+                variant=new_var,
+                content=old_comment.get("content"),
+                comment_level=old_comment.get("level"),
+            )
+            if updated_comment:
+                new_comments += 1
+
+        return new_comments
