@@ -45,8 +45,9 @@ def panels():
                 institute_id=request.form["institute"],
                 panel_name=new_panel_name,
                 display_name=request.form["display_name"],
-                description=request.form["description"],
                 csv_lines=lines,
+                maintainer=[current_user._id],
+                description=request.form["description"],
             )
             if new_panel_id is None:
                 flash(
@@ -54,24 +55,33 @@ def panels():
                     "warning",
                 )
                 return redirect(request.referrer)
-            else:
-                flash("new gene panel added, {}!".format(new_panel_name), "success")
+
+            flash("new gene panel added, {}!".format(new_panel_name), "success")
             return redirect(url_for("panels.panel", panel_id=new_panel_id))
 
-        else:  # modify an existing panel
-            update_option = request.form["modify_option"]
+        # modify an existing panel
+        update_option = request.form["modify_option"]
+
+        panel_obj = store.gene_panel(request.form["panel_name"])
+        if panel_obj is None:
+            return abort(
+                404, "gene panel not found: {}".format(request.form["panel_name"])
+            )
+
+        if panel_write_granted(panel_obj, current_user):
             panel_obj = controllers.update_panel(
                 store=store,
                 panel_name=request.form["panel_name"],
                 csv_lines=lines,
                 option=update_option,
             )
-            if panel_obj is None:
-                return abort(
-                    404, "gene panel not found: {}".format(request.form["panel_name"])
-                )
-            else:
-                return redirect(url_for("panels.panel", panel_id=panel_obj["_id"]))
+        else:
+            flash(
+                "Permission denied: please ask a panel maintainer or admin for help.",
+                "danger",
+            )
+
+        return redirect(url_for("panels.panel", panel_id=panel_obj["_id"]))
 
     institutes = list(user_institutes(store, current_user))
     panel_names = [
@@ -99,6 +109,14 @@ def panels():
     )
 
 
+def panel_write_granted(panel_obj, user):
+    return (
+        not panel_obj.get("maintainer")
+        or user.is_admin
+        or user._id in panel_obj.get("maintainer")
+    )
+
+
 @panels_bp.route("/panels/<panel_id>", methods=["GET", "POST"])
 @templated("panels/panel.html")
 def panel(panel_id):
@@ -108,7 +126,14 @@ def panel(panel_id):
     if request.method == "POST":
         if request.form.get("update_description"):
             panel_obj["description"] = request.form["panel_description"]
-            store.update_panel(panel_obj=panel_obj)
+
+            if panel_write_granted(panel_obj, current_user):
+                store.update_panel(panel_obj=panel_obj)
+            else:
+                flash(
+                    "Permission denied: please ask a panel maintainer or admin for help.",
+                    "danger",
+                )
             return redirect(url_for("panels.panel", panel_id=panel_obj["_id"]))
 
         raw_hgnc_id = request.form["hgnc_id"]
@@ -117,7 +142,7 @@ def panel(panel_id):
         hgnc_id = 0
         try:
             hgnc_id = int(raw_hgnc_id)
-        except:
+        except ValueError:
             flash("Provided HGNC is not valid : '{}'".format(raw_hgnc_id), "danger")
             return redirect(request.referrer)
         action = request.form["action"]
@@ -160,10 +185,18 @@ def panel_update(panel_id):
             flash("Pending actions were correctly canceled!", "success")
 
         return redirect(request.referrer)
-    else:
+
+    if panel_write_granted(panel_obj, current_user):
         update_version = request.form.get("version", None)
         new_panel_id = store.apply_pending(panel_obj, update_version)
-    return redirect(url_for("panels.panel", panel_id=new_panel_id))
+        panel_id = new_panel_id
+    else:
+        flash(
+            "Permission denied: please ask a panel maintainer or admin for help.",
+            "danger",
+        )
+
+    return redirect(url_for("panels.panel", panel_id=panel_id))
 
 
 @panels_bp.route("/panels/export-panel/<panel_id>", methods=["GET", "POST"])
