@@ -1,4 +1,4 @@
-from scout.constants import CLINSIG_MAP
+from scout.constants import CLINSIG_MAP, TRUSTED_REVSTAT_LEVEL
 import re
 from pymongo import ReturnDocument
 
@@ -338,7 +338,7 @@ def test_build_clinsig_always(real_variant_database):
     adapter = real_variant_database
     case_id = "cust000"
     clinsig_confident_always_returned = True
-    trusted_revstat_lev = ["mult", "single", "exp", "guideline"]
+    trusted_revstat_lev = TRUSTED_REVSTAT_LEVEL
     clinsig_items = [4, 5]
     clinsig_mapped_items = []
     all_clinsig = []  # both numerical and human readable values
@@ -374,19 +374,14 @@ def test_build_clinsig_always(real_variant_database):
         {
             "clnsig": {
                 "$elemMatch": {
-                    "$or": [
+                    "$and": [
                         {
-                            "$and": [
+                            "$or": [
                                 {"value": {"$in": all_clinsig}},
-                                {"revstat": {"$in": trusted_revstat_lev}},
-                            ]
-                        },
-                        {
-                            "$and": [
                                 {"value": re.compile("|".join(clinsig_mapped_items))},
-                                {"revstat": re.compile("|".join(trusted_revstat_lev))},
                             ]
                         },
+                        {"revstat": re.compile("|".join(trusted_revstat_lev))},
                     ]
                 }
             }
@@ -478,7 +473,7 @@ def test_build_spidex_high(adapter):
 def test_build_clinsig_always_only(adapter):
     case_id = "cust000"
     clinsig_confident_always_returned = True
-    trusted_revstat_lev = ["mult", "single", "exp", "guideline"]
+    trusted_revstat_lev = TRUSTED_REVSTAT_LEVEL
     clinsig_items = [4, 5]
     clinsig_mapped_items = []
     all_clinsig = []  # both numerical and human readable values
@@ -496,19 +491,14 @@ def test_build_clinsig_always_only(adapter):
 
     assert mongo_query["clnsig"] == {
         "$elemMatch": {
-            "$or": [
+            "$and": [
                 {
-                    "$and": [
+                    "$or": [
                         {"value": {"$in": all_clinsig}},
-                        {"revstat": {"$in": trusted_revstat_lev}},
-                    ]
-                },
-                {
-                    "$and": [
                         {"value": re.compile("|".join(clinsig_mapped_items))},
-                        {"revstat": re.compile("|".join(trusted_revstat_lev))},
                     ]
                 },
+                {"revstat": re.compile("|".join(trusted_revstat_lev))},
             ]
         }
     }
